/*******************
Ad Format: Deluxe Banner
Amazon Template Version: 1.0.0
Last Updated On: 2021-07-30
*******************/

/*******************
VARIABLES
*******************/
var creativeId = "DeluxeBanner";
var creativeVersion = "1.0.0";
var lastModified = "2021-07-30";
var dimensions;
var scrollPos = {
	x: 0,
	y: 0
};
var bannerDiv, adId, rnd, uid;

/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	if (window.adkit) {
		adkit.onReady(initializeCreative);
	}
	else {
		initializeCreative();
	}
}

function initializeCreative(event) {
    //some elements need to be defined for the ad to display correctly when tested locally
	try {
        if(EB._isLocalMode){
            EB._adConfig = { 
                adId: 0,
                rnd: 0,
                uid: 0, 
            };
            EB._sendMessage = function() {return;};
            EBG.pm.bind = function(){ return true; };
        }
	}
	catch (e) {}

	//bind the events that are present in the event manager so that messaging will work in safe frames
	EBG.pm.bind("sendCreativeId", function() {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function() {
		eventManager.apply(this, arguments);
	}, this);
    
    //global variables needed for the event manager to function correctly
    adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
    uid = EB._adConfig.uid;
    bannerDiv = document.getElementById("amz_main");
	dimensions = document.getElementById("dimensions");
    
	addEventListeners();
	displayDimensions();
	setCreativeVersion();
}

function addEventListeners() {
    overlay_hotspot.addEventListener("click", handleOverlayHotspotClick);
	user_action_btn.addEventListener("click", handleUserActionButtonClick);
	cta_btn.addEventListener("click", handleCTAButtonClick);

	window.addEventListener("resize", displayDimensions);
}

/*******************
EVENT HANDLERS
*******************/
function handleOverlayHotspotClick(event) {
	EB.clickthrough("Click_Main");
}

function handleUserActionButtonClick(event) {
	EB.userActionCounter("User_Action");
}

function handleCTAButtonClick(event) {
	EB.clickthrough("Click_CTA");
}

function onPageScroll(event) {
	//use scrollPos anywhere to know the current x/y coordinates.
	scrollPos.x = event.scrollXPercent;
	scrollPos.y = event.scrollYPercent;
	displayDimensions();
}

/*******************
UTILITIES
*******************/
function displayDimensions() {
	if (dimensions) {
		var iw = window.innerWidth,
			ih = window.innerHeight,
			sx = scrollPos.x,
			sy = scrollPos.y;
		var str = iw + "x" + ih;
		dimensions.innerHTML = str;
	}
}

function setCreativeVersion() {
	sendMessage("setCreativeVersion", {
		creativeId: creativeId,
        creativeVersion: creativeVersion,
		creativeLastModified: lastModified,
		uid: uid
	});
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {
	//note: the message type we're sending is also the name of the function inside
	//		the custom script's messageHandlers object, so the case must match.

	if (!data.type) data.type = type;
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if (listenerQueue[listenerId])
		delete listenerQueue[listenerId];
}

function eventManager(event) {
	var msg;
	if (typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);

	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}
	if (msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch (msg.type) {
			case "sendCreativeId":
				creativeIFrameId = msg.data.creativeIFrameId;
				addCustomScriptEventListener('pageScroll', onPageScroll);
				sendMessage("dispatchScrollPos", {
					uid: uid
				});
				if (creativeContainerReady)
					creativeContainerReady();
				break;
			case "eventCallback": // Handle Callback
				var list = msg.data.listenerIds;
				var length = list.length;
				for (var i = 0; i < length; i++) {
					try {
						var t = listenerQueue[list[i]];
						if (!t) continue;
						t.callback(msg.data);
					}
					catch (e) {}
				}
				break;
		}
	}
}

window.addEventListener("message", function() {
	try {
		eventManager.apply(this, arguments);
	}
	catch (e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

window.addEventListener("load", checkIfAdKitReady);